@@ -1,12 +1,14 @@
 //! Module for managing running child processes
 
+use std::time::Duration;
+use std::sync::mpsc::channel;
+
 use anyhow::anyhow;
 use log::{debug, error, trace, warn};
 use serde::{Deserialize, Serialize};
 use sysinfo::{Pid, ProcessExt, RefreshKind, Signal, System, SystemExt};
 use tokio::io::{AsyncBufReadExt, BufReader};
 use tokio::process::Child;
-use tokio::sync::mpsc::channel;
 
 use crate::plugin_models::PactPluginManifest;
 
@@ -28,7 +30,7 @@ pub struct ChildPluginProcess {
 impl ChildPluginProcess {
   /// Start the child process and try read the startup JSON message from its standard output.
   pub async fn new(mut child: Child, manifest: &PactPluginManifest) -> anyhow::Result<Self> {
-    let (tx, mut rx) = channel(1);
+    let (tx, rx) = channel();
     let child_pid = child.id()
       .ok_or_else(|| anyhow!("Could not get the child process ID"))?;
     let child_out = child.stdout.take()
@@ -36,6 +38,8 @@ impl ChildPluginProcess {
     let child_err = child.stderr.take()
       .ok_or_else(|| anyhow!("Could not get the child process standard error stream"))?;
 
+    trace!("Starting output polling tasks...");
+
     let mfso = manifest.clone();
     tokio::task::spawn(async move {
       trace!("Starting task to poll plugin stdout");
@@ -56,12 +60,12 @@ impl ChildPluginProcess {
                     child_pid: child_pid as usize,
                     manifest: mfso.clone(),
                     plugin_info
-                  })).await.unwrap_or_default()
+                  })).unwrap_or_default()
                 }
                 Err(err) => {
                   error!("Failed to read startup info from plugin - {}", err);
                   tx.send(Err(anyhow!("Failed to read startup info from plugin - {}", err)))
-                    .await.unwrap_or_default()
+                    .unwrap_or_default()
                 }
               }
             }
@@ -84,11 +88,15 @@ impl ChildPluginProcess {
       trace!("Task to poll plugin stderr done");
     });
 
-    match rx.recv().await {
-      Some(result) => result,
-      None => {
-        error!("Timeout waiting to get plugin startup info");
-        Err(anyhow!("Plugin process did not output the correct startup message"))
+    trace!("Starting output polling tasks... DONE");
+
+    // TODO: This timeout needs to be configurable
+    // TODO: Timeout is not working on Alpine, waits indefinitely if the plugin does not start properly
+    match rx.recv_timeout(Duration::from_secs(60)) {
+      Ok(value) => value,
+      Err(err) => {
+        error!("Timeout waiting to get plugin startup info: {}", err);
+        Err(anyhow!("Plugin process did not output the correct startup message in 60 seconds: {}", err))
       }
     }
   }
