@@ -39,7 +39,7 @@ impl PactPluginRpc for MockPlugin {
   }
 }
 
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 async fn test_proto_client() {
   let _ = env_logger::builder().is_test(true).try_init();
 
@@ -48,10 +48,12 @@ async fn test_proto_client() {
     .using_plugin("protobuf", None).await
     .synchronous_message_interaction("init plugin request", "core/interaction/synchronous-message", |mut i| async move {
       let project_dir = Path::new(option_env!("CARGO_MANIFEST_DIR").unwrap());
-      let proto_file = project_dir.join("plugin.proto")
-        .canonicalize().unwrap().to_string_lossy().to_string();
+      println!("project_dir = {:?}", project_dir);
+      let proto_file = project_dir.join("plugin.proto");
+      println!("proto_file = {:?}", proto_file);
+
       i.contents_from(json!({
-          "pact:proto": proto_file,
+          "pact:proto": proto_file.to_str().unwrap(),
           "pact:content-type": "application/protobuf",
           "pact:proto-service": "PactPlugin/InitPlugin",
           "request": {
